# Salesforce Messaging for Web Module

## Introduction

The Salesforce Messaging for Web module integrates Salesforce utility features
into Drupal, allowing administrators to configure and manage Salesforce
`Messaging for Web`
https://developer.salesforce.com/docs/service/messaging-web/references/m4w-reference/overview.html
services.

## Installation

1. Download and install the module in the usual Drupal manner.
2. Enable the Salesforce Messaging for Web module at `/admin/modules`.

## Features
- Multiple Block Support: Add multiple Salesforce MFW blocks to your site with
different configurations. Ensure only one block is displayed per page to
avoid conflicts.
- Configurable Fields: Add and manage pre-chat fields with default values,
visibility options, and user-editable settings.
- Token Replacement: Enable token replacement in default values to dynamically populate field values.
- Persistent chat option: Persist a chat interaction across all pages.

### Permissions

The module provides the following permission:
**_Please note that this permission has potential security implications.
Be Careful who you assign this to._**

- **Administer Salesforce Configuration**: Allows users to view and
update Salesforce configuration options and place salesforce_mfw block plugins.


### Block Plugin


#### Pre-Chat Fields

Administrators can configure pre-chat fields with default values and visibility
settings. These fields can be set as visible or hidden, and whether they are
editable by the end-user.

### JavaScript Integration

The module includes JavaScript behaviors to extend and customize the Salesforce
Messaging for Web configuration on the client-side. The example below
demonstrates how to override Salesforce configuration fields based on
specific conditions or external data:

```javascript
/**
 * @file
 * JavaScript behaviors for extending the Salesforce Messaging for Web API.
 */
(function (Drupal, cookies) {
  Drupal.behaviors.salesforceChatConfiguration = {
    attach: function (context) {
      window.addEventListener('SalesforceMFWConfig', function (e) {
        // Override default values of Salesforce configuration fields
        e.detail.fields.Visitor_URL.default_value = window.location.href;

        // Example: Set CID field from cookie if available
        if (typeof cookies.get('CID') !== 'undefined') {
          e.detail.fields.CID.default_value = cookies.get('CID');
        }

        // Example: Initialize Google Client ID asynchronously
        (function initGoogleClientId() {
          if (typeof gaGlobal !== 'undefined' &&
            typeof gaGlobal.vid !== 'undefined') {
            e.detail.fields.Google_Client_ID.default_value = gaGlobal.vid;
          } else {
            // Retry in case Google Analytics or GTM is still loading
            setTimeout(initGoogleClientId, 500);
          }
        })();
      });
    }
  };
})(Drupal, window.Cookies);
```
# Salesforce Messaging for Web JavaScript Integration and API Extension

## Explanation

### Event Listener (`SalesforceMFWConfig`)

The script listens for the `SalesforceMFWConfig` event, dispatched
by your Drupal module when Salesforce Messaging for Web configuration is
prepared client-side.

### Override Configuration Fields

Inside the event listener, modify fields in `e.detail.fields` as needed.
For example:
- `Visitor_URL.default_value`: Sets default value to current page URL.
- `CID.default_value`: Sets value from 'CID' cookie if available.
- `Google_Client_ID.default_value`: Asynchronously initializes Google
Client ID, retrying until loaded.

## Integration

- Include this JavaScript in your Drupal module's library.
- Ensure cookies (or preferred library) are available in Drupal site.
- Update javascript accordingly to your business needs.

## Extending the API

Expand module's API:
- Add custom field overrides to your `salesforce_mfw` block plugin instance
- Modify JavaScript for custom Salesforce features.
- Use hooks/events for Drupal or external system integration.

## Maintainers

Salesforce Messaging for Web is provided to the community by initiatives at
Penn State University World Campus Outreach Marketing
[https://www.worldcampus.psu.edu]

- [Kyle Leber] (https://www.drupal.org/u/kjl16), Application Developer
- [Luke Leber] (https://www.drupal.org/u/lukeleber), Application Developer
