<?php

namespace Drupal\salesforce_mfw\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\Routing\Route;

/**
 * Custom access check that applies to Salesforce mfw blocks.
 */
class SalesforceMfwAccessCheck implements AccessInterface {

  /**
   * {@inheritdoc}
   */
  public function access(RouteMatchInterface $route_match, AccountInterface $account, Route $route) {
    $operation = $route->getRequirement('_salesforce_mfw_access');
    if ($operation === 'create') {
      $plugin_id = $route_match->getParameter('plugin_id');
      if ($plugin_id === 'salesforce_mfw') {
        return AccessResult::allowedIfHasPermission($account, 'administer salesforce_mfw blocks');
      }
    }
    else {
      $block = $route_match->getParameter('block');
      $plugin_id = $block->getPluginId();
      if ($plugin_id === 'salesforce_mfw') {
        return AccessResult::allowedIfHasPermission($account, 'administer salesforce_mfw blocks');
      }
    }

    return AccessResult::neutral();
  }

}
