<?php

namespace Drupal\Tests\salesforce_mfw\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\user\Traits\UserCreationTrait;

/**
 * Tests the Salesforce MFW block configuration form.
 *
 * @group salesforce_mfw
 */
class SalesforceMfwBlockTest extends BrowserTestBase {

  use UserCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['salesforce_mfw', 'block', 'user'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests the block form without permission.
   */
  public function testBlockFormAccessDenied() {
    $this->drupalGet('admin/structure/block/add/salesforce_mfw');
    $this->assertSession()->statusCodeEquals(403);
  }

  /**
   * Tests adding and saving the basic configuration of the form.
   */
  public function testSubmitFormConfig() {
    $adminUser = $this->createUser([
      'administer blocks',
      'administer site configuration',
      'administer salesforce_mfw blocks',
    ]);

    $this->drupalLogin($adminUser);
    $this->drupalGet('admin/structure/block/add/salesforce_mfw');
    $this->assertSession()->statusCodeEquals(200);
    $this->fillForm();
    $this->assertSession()->buttonExists('Add Field');
    $this->getSession()->getPage()->pressButton('Add Field');
    $this->assertSession()->pageTextContains('Name');
    $this->assertSession()->pageTextContains('Default value');
    $this->assertSession()->pageTextContains('Editable by user');
    $this->assertSession()->fieldExists('Name');
    $this->getSession()->getPage()->fillField('Name', 'first name');
    $this->getSession()->getPage()->fillField('Default value', 'test');
    $this->getSession()->getPage()->fillField('Hidden', FALSE);
    $this->getSession()->getPage()->fillField('Editable by user', TRUE);
    $this->getSession()->getPage()->pressButton('Save block');
    $this->assertSession()->pageTextContains('The block configuration has been saved.');
    $this->drupalGet('admin/structure/block/manage/salesforcemfw');
    $this->assertSession()->fieldValueEquals('Name', 'first name');
    $this->assertSession()->fieldValueEquals('Default value', 'test');
    $this->assertSession()->fieldValueEquals('Hidden', FALSE);
    $this->assertSession()->fieldValueEquals('Editable by user', TRUE);
    $this->getSession()->getPage()->pressButton('Remove');
    $this->getSession()->getPage()->pressButton('Save block');
    $this->drupalGet('admin/structure/block/manage/salesforcemfw');
    $this->assertSession()->pageTextContains('No fields added yet.');

  }

  /**
   * Helper function to fill out form.
   */
  private function fillForm() {
    $this->getSession()->getPage()->fillField('Organization id', 'TestOrgID');
    $this->getSession()->getPage()->fillField('Config name', 'TestConfig');
    $this->getSession()->getPage()->fillField('Site url', 'http://example.com');
    $this->getSession()->getPage()->fillField('Snippet config url', 'http://example.com/snippet');
    $this->getSession()->getPage()->fillField('Utility bootstrap', 'http://example.com/bootstrap');
    $this->getSession()->getPage()->fillField('Language', 'en_US');
    $this->getSession()->getPage()->fillField('Region', 'content');

  }

}
