<?php

namespace Drupal\Tests\salesforce_mfw\Functional;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\Tests\user\Traits\UserCreationTrait;

/**
 * Tests the Salesforce MFW block token replacement feature.
 *
 * @group salesforce_mfw
 */
class SalesforceMfwBlockTokenReplacementTest extends WebDriverTestBase {

  use UserCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'salesforce_mfw',
    'block',
    'user',
    'token',
  ];

  /**
   * The block configuration to setup.
   *
   * @var array
   */
  protected $blockConfig;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->blockConfig = [
      'id' => 'salesforcemfw',
      'plugin' => 'salesforce_mfw',
      'region' => 'content',
      'label' => 'Salesforce MFW Block',
      'label_display' => 'invisible',
      'organization_id' => 'organization_id',
      'config_name' => 'test_configuration',
      'site_url' => 'http://example.com',
      'snippet_config' => 'http://example.com/snippet',
      'utility_bootstrap' => 'http://example.com/bootstrap',
      'language' => 'en_US',
      'prechat_fields' => [
        [
          'name' => 'first name',
          'default_value' => '[current-user:name]',
          'hidden' => FALSE,
          'editable_by_user' => TRUE,
        ],
      ],
    ];

    $user = $this->drupalCreateUser(['access content']);
    $user->set('name', 'Test User');
    $user->save();
    $this->drupalLogin($user);
  }

  /**
   * Tests token replacement on prechat fields when enabled.
   */
  public function testTokenReplacementEnabled() {
    $this->drupalPlaceBlock($this->blockConfig['plugin'], $this->blockConfig + ['allow_token_replacement' => TRUE]);
    $this->drupalGet('<front>');
    $prechat_fields = $this->getSession()->evaluateScript('return drupalSettings.salesforce_mfw.test_configuration.configuration.prechat_fields;');
    $this->assertEquals('Test User', $prechat_fields[0]['default_value']);
  }

  /**
   * Tests token replacement on prechat fields when disabled.
   */
  public function testTokenReplacementDisabled() {
    $this->drupalPlaceBlock($this->blockConfig['plugin'], $this->blockConfig + ['allow_token_replacement' => FALSE]);
    $this->drupalGet('<front>');
    $prechat_fields = $this->getSession()->evaluateScript('return drupalSettings.salesforce_mfw.test_configuration.configuration.prechat_fields;');
    $this->assertEquals("[current-user:name]", $prechat_fields[0]['default_value']);
  }

}
