<?php

namespace Drupal\Tests\salesforce_mfw\Kernel;

use Drupal\KernelTests\KernelTestBase;

/**
 * Tests the RouteSubscriber.
 *
 * @group salesforce_mfw
 */
class RouteSubscriberTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'salesforce_mfw',
    'block',
  ];

  /**
   * Tests the route's requirements.
   */
  public function testRouteAlterations() {
    $route_provider = \Drupal::service('router.route_provider');
    $routes = [
      'entity.block.delete_form',
      'entity.block.edit_form',
      'entity.block.enable',
      'entity.block.disable',
      'block.admin_add',
    ];

    foreach ($routes as $route_name) {
      $route = $route_provider->getRouteByName($route_name);
      $operation = $route->getRequirement('_salesforce_mfw_access');
      // Get the expected operation by matching against RouteSubscriber.
      $expected_operation = match ($route_name) {
        'entity.block.delete_form' => 'delete',
        'entity.block.edit_form' => 'edit',
        'entity.block.enable' => 'enable',
        'entity.block.disable' => 'disable',
        'block.admin_add' => 'create',
      };

      $this->assertEquals($expected_operation, $operation, "Route $route_name has the correct _salesforce_mfw_access requirement.");
    }
  }

}
